﻿using System;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using System.Collections.Generic;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;

public partial class _Default : System.Web.UI.Page
{
    #region events
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!Page.IsPostBack)
        {
            InitializeModuleCarto();
            InitializeMarkers();
            addMarkers();
        }

    }
    /// <summary>
    /// To get a postback after a pan or zoom to see the behaviour of the markers
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btReload_Click(object sender, EventArgs e)
    {

    }
    #endregion


   
    /// <summary>
    /// Initialize the map, with appearence and background layer
    /// </summary>
    #region Module Carto Initialisation

    private void InitializeModuleCarto()
    {
        InitializeInchedPerUnit();
        InitializeMapAppearance();
        InitializeBackgroundLayer();
    
        Map1.MapUnit = GeographyUnit.Meter;
    }

    #region Init Current Scale
    public const int DotsPerInch = 96;
    public Dictionary<string, double> inchesPerUnits;

    public void InitializeInchedPerUnit()
    {
        inchesPerUnits = new Dictionary<string, double>();
        inchesPerUnits.Add("DecimalDegree", 4374754);
        inchesPerUnits.Add("Feet", 12.0);
        inchesPerUnits.Add("Meter", 39.3701);
    }
    #endregion

    private void InitializeMapAppearance()
    {
        Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
        Map1.MapTools.OverlaySwitcher.Enabled = false;
        Map1.MapTools.MouseCoordinate.Enabled = true;
        Map1.MapTools.PanZoomBar.Enabled = true;
        Map1.MapTools.ScaleLine.Enabled = true;
        Map1.MapTools.Logo.Enabled = true;
        Map1.EditOverlay.EditSettings.IsDraggable = true;
        Map1.EditOverlay.EditSettings.IsReshapable = true;
        Map1.EditOverlay.EditSettings.IsResizable = false;
        Map1.EditOverlay.EditSettings.IsRotatable = false;

        Map1.EditOverlay.Style.FillColor = GeoColor.FromArgb(77, 255, 255, 0);
        Map1.EditOverlay.Style.OutlineColor = GeoColor.FromArgb(77, 255, 255, 0);
        Map1.EditOverlay.Style.OutlineWidth = 3;


    }

    private void InitializeBackgroundLayer()
    {

        GoogleOverlay gOverlay = new GoogleOverlay();
        gOverlay.Name = "Google Overlay";
        gOverlay.GoogleMapType = GoogleMapType.Hybrid;

        gOverlay.JavaScriptLibraryUri = new Uri("http://maps.google.com/maps?file=api&amp;v=2&amp;client=gme-geosys&amp;sensor=false");
        gOverlay.IsBaseOverlay = true;
        Map1.CustomOverlays.Add(gOverlay);

    }

  

    #endregion

    #region markers

    /// <summary>
    /// Marker styles
    /// </summary>
    public enum MarkerType { YELLOW, RED, BLUE, GREEN }
    class FieldMarkerStyle : PointMarkerStyle
    {
        public FieldMarkerStyle(string urlImage)
        {
            this.WebImage = new WebImage(urlImage);
            this.Popup.ContentHtml = "<span class='popup'>[#MARKERNAME#]</span>";
            this.Popup.Width = 60;
            this.Popup.Height = 60;
            this.Popup.IsVisible = false;
            this.Popup.AutoSize = true;
            this.Popup.AutoPan = true;
        }
    }
    class MyPoint
    {
        private string _wkt;
        private string _name;
        public string WKT { get { return _wkt; } set { _wkt = value; } }
        public string NAME { get { return _name; } set { _name = value; } }
        public MyPoint(string sname, string swkt) { _name = sname; _wkt = swkt; }

    }

    /// <summary>
    /// Create a new InMemoryMarkerOverlay
    /// </summary>
    private void InitializeMarkers()
    {
        ValueMarkerStyle valueStyle = new ValueMarkerStyle("MARKERTYPE");

        MarkerValueItem markerValueItemRED = new MarkerValueItem(MarkerType.RED.ToString(), new FieldMarkerStyle("marker.gif"));
        valueStyle.ValueItems.Add(markerValueItemRED);

        InMemoryMarkerOverlay markerPointOverlay = new InMemoryMarkerOverlay("MARKERS");
        markerPointOverlay.ZoomLevelSet.ZoomLevel01.CustomMarkerStyle = valueStyle;
        markerPointOverlay.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

        markerPointOverlay.FeatureSource.Open();
        markerPointOverlay.Columns.Add(new FeatureSourceColumn("MARKERTYPE"));
        markerPointOverlay.Columns.Add(new FeatureSourceColumn("MARKERNAME"));
        markerPointOverlay.FeatureSource.Close();

        Map1.CustomOverlays.Add(markerPointOverlay);
    }

    /// <summary>
    /// Add markers and zoom to an extent we are sure some markers are out of it: Austria and Greece
    /// </summary>
    private void addMarkers()
    {
        InMemoryMarkerOverlay markerOverlay = (InMemoryMarkerOverlay)Map1.CustomOverlays["MARKERS"];
        markerOverlay.Features.Clear();

        List<MyPoint> liste = new List<MyPoint>();
        liste.Add(new MyPoint("Paris", "POINT(269058.33952637 6251937.4166309)"));
        liste.Add(new MyPoint("Londres", "POINT(-9783.9396191406 6716674.54854)"));
        liste.Add(new MyPoint("Madrid", "POINT(-415817.43381348 4931105.5680469)"));
        liste.Add(new MyPoint("Bern", "POINT(826742.89781738 5932736.3865564) "));
        liste.Add(new MyPoint("Bruxelles", "POINT(486750.99605225 6595598.2957532)"));
        liste.Add(new MyPoint("Luxembourg", "POINT(682429.78843506 6379128.6316797)"));
        liste.Add(new MyPoint("Berlin", "POINT(1492050.7919189 6897677.43149409)"));
        liste.Add(new MyPoint("Rome", "POINT(1389319.425918 5148798.2245728)"));
        liste.Add(new MyPoint("Vienne", "POINT(1819812.7691602 6141868.0959155)"));
        liste.Add(new MyPoint("Athene", "POINT(2641663.697168 4573991.7719482)"));

        foreach (MyPoint pt in liste)
        {
            Feature feature = new PointShape(pt.WKT).GetFeature();
            feature.ColumnValues.Add("MARKERTYPE", MarkerType.RED.ToString());
            feature.ColumnValues.Add("MARKERNAME", pt.NAME);
            markerOverlay.FeatureSource.Open();
            markerOverlay.Features.Add(feature);
            markerOverlay.FeatureSource.Close();
        }

        Map1.CurrentExtent = new RectangleShape("POLYGON((-533251.307718221 6637425.87816618,1064461.68389224 6637425.87816618,1064461.68389224 5066317.94459259,-533251.307718221 5066317.94459259,-533251.307718221 6637425.87816618))");
        markerOverlay.IsVisible = true;
    }

    #endregion



}
